@@ -1,2 +1,2 @@
-from .message import GRIBMessage, Message  # noqa
+from .message import BUFRMessage, GRIBMessage, Message  # noqa
 from .reader import FileReader, MemoryReader, StreamReader  # noqa
