@@ -17,7 +17,7 @@ def raise_keyerror(name):
     """Make operations on a key raise a KeyError if not found"""
     try:
         yield
-    except eccodes.KeyValueNotFoundError:
+    except (eccodes.KeyValueNotFoundError, eccodes.FunctionNotImplementedError):
         raise KeyError(name)
 
 
@@ -33,7 +33,7 @@ class Message:
 
     def copy(self):
         """Create a copy of the current message"""
-        return Message(eccodes.codes_clone(self._handle))
+        return self.__class__(eccodes.codes_clone(self._handle))
 
     def __copy__(self):
         return self.copy()
@@ -242,6 +242,24 @@ class Message:
         return eccodes.codes_get_message(self._handle)
 
 
+class BUFRMessage(Message):
+    def __init__(self, handle):
+        super().__init__(handle)
+
+    def pack(self):
+        """Pack the underlying data"""
+        self.set("pack", 1, check_values=False)
+
+    def unpack(self):
+        """Unpack the underlying data"""
+        self.set("unpack", 1, check_values=False)
+
+    @classmethod
+    def from_samples(cls, name):
+        """Create a message from a sample"""
+        return cls(eccodes.codes_bufr_new_from_samples(name))
+
+
 class GRIBMessage(Message):
     def __init__(self, handle):
         super().__init__(handle)
