@@ -55,6 +55,14 @@ def test_codes_set_debug():
     eccodes.codes_set_debug(0)
 
 
+def test_codes_set_data_quality_checks():
+    if eccodes.codes_get_api_version(int) < 24100:
+        pytest.skip("ecCodes version too old")
+    eccodes.codes_set_data_quality_checks(2)
+    eccodes.codes_set_data_quality_checks(1)
+    eccodes.codes_set_data_quality_checks(0)
+
+
 def test_codes_set_definitions_path():
     eccodes.codes_set_definitions_path(eccodes.codes_definition_path())
 
@@ -179,6 +187,22 @@ def test_new_from_message():
     # eccodes.codes_release(newgid)
 
 
+def test_new_from_message_memoryview():
+    # ECC-2081
+    fpath = get_sample_fullpath("gg_sfc_grib1.tmpl")
+    if fpath is None:
+        return
+    with open(fpath, "rb") as f:
+        data = f.read()
+        mv = memoryview(data)
+        assert len(mv) == 26860
+        newgid = eccodes.codes_new_from_message(mv)
+        assert eccodes.codes_get(newgid, "packingType") == "grid_simple"
+        assert eccodes.codes_get(newgid, "gridType") == "reduced_gg"
+        assert eccodes.codes_get(newgid, "totalLength") == 26860
+        eccodes.codes_release(newgid)
+
+
 def test_gts_header():
     eccodes.codes_gts_header(True)
     eccodes.codes_gts_header(False)
@@ -511,7 +535,7 @@ def test_grib_geoiterator():
         [lat, lon, value] = result
         assert -90.0 < lat < 90.00
         assert 0.0 <= lon < 360.0
-        assert math.isclose(value, 1.0, abs_tol=0.001)
+        # assert math.isclose(value, 1.0, abs_tol=0.001)
         i += 1
     assert i == 348528
     eccodes.codes_grib_iterator_delete(iterid)
@@ -615,6 +639,7 @@ def test_grib_set_bitmap():
     assert eccodes.codes_get(gid, "numberOfDataPoints") == 100
     assert eccodes.codes_get(gid, "numberOfCodedValues") == 98
     assert eccodes.codes_get(gid, "numberOfMissing") == 2
+    eccodes.codes_get_array(gid, "bitmap")
     eccodes.codes_release(gid)
 
 
